@@ -11,14 +11,14 @@ read_tab_generic <- function(file, ext, tib_names, col_types, verbose = TRUE) {
         stop('Table column types (col_types) is required!')
     
     # add .ext and/or .gz if missing and needed
-    file <- real_path(file, ext)
+    file <- add_ext_read(file, ext)
     
     # announce what we ended up loading, nice to know
     if (verbose)
         message('Reading: ', file)
     
     # read input
-    ind <- readr::read_table2(
+    ind <- readr::read_table(
                       file,
                       col_names = tib_names,
                       col_types = col_types
